<?php

return [
    'system_configurator'         => [
        'recaptcha_site_key' => [
            'label'           => 'reCaptcha site key',
            'callback'        => 'input',
            'callbck_options' => [],
        ],
        'recaptcha_secret_key' => [
            'label'           => 'reCaptcha secret key',
            'callback'        => 'input',
            'callbck_options' => [],
        ],
    ],
];
