$(function(){
    grecaptcha.ready(function() {
        grecaptcha.execute('{site_key}', {action: 'submit'}).then(function(token) {
            $('input[name="{token_id}"]').each(function(){
                $(this).val(token);
            });
        });
    });
});