<?php

return [
    'ciext_settings' => [
        'pages' => [
            'recaptcha' => [
                'label'    => 'reCaptcha',
                'file'     => __DIR__ . '/../docs/recaptcha.md',
                'position' => 100,
            ],
        ]
    ],
];
